﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2010 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;

namespace HeuristicLab.Clients.Hive.SlaveCore {
  public class SlaveStatusInfo {
    static private int jobsFinished; // everything went fine
    static private int jobsAborted;  // server sent stop or abort
    static private int jobsFetched;  // number of fetched jobs
    static private int jobsFailed;   // jobs that failed in the sandbox
    static private int usedCores;    // number of cores currently used

    static public DateTime LoginTime { get; set; }
    static private Object jobStatLock = new Object();
    static private Object coreLock = new Object();

    static public int UsedCores {
      get {
        lock (coreLock) {
          return usedCores;
        }
      }
    }

    static public int JobsFinished {
      get {
        lock (jobStatLock) {
          return jobsFinished;
        }
      }
    }

    static public int JobsAborted {
      get {
        lock (jobStatLock) {
          return jobsAborted;
        }
      }
    }

    static public int JobsFetched {
      get {
        lock (jobStatLock) {
          return jobsFetched;
        }
      }
    }

    static public int JobsFailed {
      get {
        lock (jobStatLock) {
          return jobsFailed;
        }
      }
    }

    public static void IncrementJobsFinished() {
      lock (jobStatLock) {
        jobsFinished++;
      }
    }

    public static void IncrementJobsFailed() {
      lock (jobStatLock) {
        jobsFailed++;
      }
    }

    public static void IncrementJobsAborted() {
      lock (jobStatLock) {
        jobsAborted++;
      }
    }

    public static void IncrementJobsFetched() {
      lock (jobStatLock) {
        jobsFetched++;
      }
    }

    public static void IncrementUsedCores(int val) {
      lock (coreLock) {
        usedCores += val;
      }
    }

    public static void DecrementUsedCores(int val) {
      lock (coreLock) {
        usedCores -= val;
      }
    }
  }
}
